@@ -17,7 +17,7 @@
 // along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <ucommon/ucommon.h>
-#include <config.h>
+#include <ccaudio2-config.h>
 #include <math.h>
 
 extern int _oss_ccaudio_dummy;
